@@ -65,6 +65,8 @@ DEHUMANIZE_LOCALES = {
     "se-se",
     "sv",
     "sv-se",
+    "fi",
+    "fi-fi",
     "zh",
     "zh-cn",
     "zh-tw",
@@ -116,6 +118,10 @@ DEHUMANIZE_LOCALES = {
     "sl-si",
     "id",
     "id-id",
+    "ne",
+    "ne-np",
+    "ee",
+    "et",
     "sw",
     "sw-ke",
     "sw-tz",
@@ -130,4 +136,13 @@ DEHUMANIZE_LOCALES = {
     "or-in",
     "lb",
     "lb-lu",
+    "zu",
+    "zu-za",
+    "sq",
+    "sq-al",
+    "ta",
+    "ta-in",
+    "ta-lk",
+    "ur",
+    "ur-pk",
 }
